class ApplicationController < ActionController::Base
  include SimpleCaptcha::ControllerHelpers
  
  #Makes method available from views
  helper_method :current_user
  helper_method :fg_color
  helper_method :bg_color
  helper_method :current_blog
  helper_method :sidebar_header
  helper_method :current_title
  helper_method :available_pages
  helper_method :link_to_method
  helper_method :user_fname
  helper_method :path_from_post

  add_flash_types :alerts

  def current_user
    @current_user ||= User.find(session[:user_id]) if session[:user_id]
  end

  def fg_color
	return @blog.fg if @blog && !@blog.fg.nil?
	return @post.blog.fg if @post && !@post.blog.fg.nil?
	return default_fg_color
  end

  def bg_color
	return @blog.bg if @blog && !@blog.bg.nil?
	return @post.blog.bg if @post && !@post.blog.bg.nil?
	return default_bg_color
  end

  def current_blog
    return @blog if @blog
    return @post.blog if @post
    return nil
  end

  def get_user_blog
    return nil if current_user.nil?
    blog = Blog.find_by(urlName: params[:blog_name], user_id: current_user.id)
    return blog
  end

  def sidebar_header
	return @sidebar_header
  end

  def current_title
	#Problems caused by naming the page num @page
	if @page && !(@page.is_a? Integer)
	  return @page.friendly_title + " | " + @page.blog.title unless @page.title.nil?
	  return "New page"
	end
	return @post.friendly_title + " | " + @post.blog.title if @post && @post.title
	return @blog.title if @blog
    return @page_title if @page_title
	return "Pressr"
  end

  def available_pages
    return [] if current_blog.nil?
    pages = current_blog.pages.where(hidden: false)
    unless current_blog.can_edit(current_user)
      pages = pages.where(is_draft: false)
    end
    return pages.order(priority: :asc)
  end

  def link_to_method(title, url, opts = {})
    if opts[:method].nil? || opts[:method] == :get
      return link_to(title, url, opts)
    end
    link_class = opts[:class] || "inline-link-button"
    form = <<html
<form method="#{opts[:method].to_s}" action="#{url}" class="inline-link-form">
  <input type="hidden" name="authenticity_token" value="#{form_authenticity_token}">
  <button type="submit" class="#{link_class}">
    #{title}
  </button>
</form>
html
    return form.html_safe
  end

  def user_fname(user = current_user)
    return nil if user.nil?
    return helpers.link_to(
             "<span style='color: #{user.color}'>#{user.display_name}</span>".html_safe,
             user_path(user.username)
           )
  end

  def path_from_post(post)
    return post_path(
             blog_name: post.blog.urlName,
             post_id: post.id
           )
  end

  def auth_user
    if current_user.nil?
      flash[:alert] = "Please login first."
      redirect_to login_path
    elsif get_user_blog.nil? || !get_user_blog.can_edit(current_user)
      flash[:alert] = "You do not have access to that page!"
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
    end
  end

  private

  def default_bg_color
	'#ffffff'
  end

  def default_fg_color
	'#555555'
  end
end
