class BlogController < ApplicationController
  def summary
    StatsD.increment("blog.summary")
    @posts = Post
               .where(is_draft: false)
               .order(created_at: :desc)
               .preload(:blog)
               .all #todo, probably

    @page = params[:page].try(:to_i)
    @page = 1 if @page.nil? || @page < 1
    @page_count = (@posts.count / 10.0).ceil
    @posts = @posts.limit(10).offset((@page - 1)*10).preload_comment_counts.preload(:categories).all
    @has_next =  @page < @page_count
    @has_prev = @page > 1
	@sidebar_header = <<HEADER
	 <h1>Recent Posts</h1>
	 Showing recent posts from all blogs.
HEADER
	@sidebar_header = @sidebar_header.html_safe
  end

  def edit
    if current_user.nil? || !current_user.can_create_blog
      redirect_back(fallback_location: root_path)
      return
    end
    @blog = current_user.blogs.where(urlName: params[:blog_name]).take || Blog.new
	#This is better than having a default colour in the BD
	#Because it means we only have to change it in one place
	#:. DRYer
	@blog.bg = bg_color if @blog.bg_color.nil?
	@blog.fg = fg_color if @blog.fg_color.nil?
  end

  def update
    StatsD.increment("blog.update")

    if current_user.nil?
      redirect_back(fallback_location: root_path)
      return
    end
    
    blog = Blog.find_by(id: params[:blog_id])
    if (!blog.nil? && blog.user_id != current_user.id) || !current_user.can_create_blog
      redirect_back(fallback_location: root_path)
      return
    end
    
    if blog.nil?
      blog = Blog.new(urlName: params[:blog][:urlName], user: current_user)
    end

    unless blog.update(blog_params)
      flash.now[:alerts] = blog.errors.messages.map { |k,v| v[0] }
      @blog = blog
      render :edit
      return
    end
    
    redirect_to dashboard_path
  end

  def search
    StatsD.increment("blog.search")
    @q = params[:q]
    @results = Post.search(@q)
                 .includes(blog: :user)
                 .includes(:comments)
                 .all
    @sidebar_header = "<h1>Search</h1>".html_safe
    @page_title = "Search Results for \"#{params[:q]}\""
  end

  private
  
  def blog_params
    params[:blog].permit(:title, :img_url, :slogan, :fg, :bg, :logo)
  end
end
