class PageController < ApplicationController
  def get
    StatsD.increment("page.get")
    @blog = Blog.find_by(urlName: params[:blog_name])
    @page = Page.find_by(id: params[:id], blog: @blog)
    #Valid page, valid blog, and user is allowed to view
    #(it's a published page, or the user is the author)
    if @page.nil? || @blog.nil? || (!@blog.can_edit(current_user) && @page.is_draft)
      @page = nil
      render file: "#{Rails.root}/public/404.html" , status: :not_found
      return
    end
  end

  def manage
    @blog = get_user_blog
    if @blog.nil? || !@blog.can_edit(current_user)
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
      return
    end
    @pages = @blog.pages.order(priority: :asc).all
  end
  
  def new
    @blog = get_user_blog
    if @blog.nil? || !@blog.can_edit(current_user)
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
      return
    end
    @page = @blog.pages.new
  end

  def create
    StatsD.increment("page.create")
    @blog = get_user_blog
    if @blog.nil?
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
      return
    end
    @page = @blog.pages.create(params[:page].permit(:title, :body, :hidden, :is_draft))
    unless @page.save
      flash.now[:alerts] = @page.errors.full_messages
      render :new
      return
    end
    redirect_to edit_page_path(id: @page.id, path: @page.path)
  end

  def edit
    @page = Page.find(params[:id])
    @blog = @page.blog
    if @blog.nil? || !@blog.can_edit(current_user)
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
      return
    end
  end

  def update
    StatsD.increment("page.update")
    @page = Page.find(params[:id])
    if @page.nil? || !@page.blog.can_edit(current_user)
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
      return
    end
	@blog = @page.blog
    unless @page.update(params[:page].permit(:title, :body, :hidden, :is_draft))
      flash.now[:alerts] = @page.errors.full_messages
      render :new
      return
    end
    render :edit
  end

  def priority
    blog = get_user_blog
    if blog.nil?
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
      return
    end

    case params[:dir]
    when 'down'
      pages = blog.pages.order(priority: :asc)
                .where('priority >= ?', params[:p])
    when 'up'
      pages = blog.pages.order(priority: :desc)
                .where('priority <= ?', params[:p])
    else
      redirect_to root_path
      return
    end
    pages = pages.limit(2).all
    unless pages.size < 2
      #Swap the priorities
      tmp = pages[0].priority
      pages[0].priority = pages[1].priority
      pages[1].priority = tmp
      pages[0].save
      pages[1].save
    end
    redirect_to manage_page_path(params[:blog_name])
  end

  def delete
    StatsD.increment("page.delete")
    blog = get_user_blog
    page = blog.try(:pages).try(:find, params[:id])
    if page.nil?
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
      return
    end
    page.destroy
    redirect_to manage_page_path(params[:blog_name])
  end
end
