class PostController < ApplicationController
  def index
    StatsD.increment("post.index")
    if !params[:blog_name].nil?
      @blog = Blog.where(urlName: params[:blog_name]).take
      @blog_name = params[:blog_name]
    elsif !params[:blog_id].nil?
      @blog = Blog.find(params[:blog_id])
      @blog_name = @blog.urlName
    else
      #We need something in here
      return
    end
    #This should 404 instead of redirect
    #"That blog could not be found"
    redirect_to root_path and return if @blog.nil?
    @page = params[:page].try(:to_i)
    @page = 1 if @page.nil? || @page < 1
    @posts = @blog.posts
    if current_user.nil? || !@blog.can_edit(current_user)
      @posts = @posts.where(is_draft: false)
    end
    @posts = @posts.order(created_at: :desc)
    @page_count = (@posts.count / 10.0).ceil
    @posts = @posts.limit(10).offset((@page - 1)*10).preload_comment_counts.preload(:categories).all
    @has_next =  @page < @page_count
    @has_prev = @page > 1

    respond_to do |format|
      format.html
      format.rss { render layout: false }
    end
  end
  
  def get
    StatsD.increment("post.get")
    @blog = Blog.find_by(urlName: params[:blog_name])
    @post = Post.find_by(id: params[:post_id].to_i)
    
    if @post && @post.is_draft && !@post.blog.can_edit(current_user)
      @post = nil
    end

    if @post.nil?
      render file: "#{Rails.root}/public/404.html",
             status: :not_found
      return
    end
    
    @comment = Comment.new
    @comments = @post.comments
                  .order(created_at: :desc).all
    @comments_count = @comments.count
    @comments = @comments
                  .where('parent_id IS NULL')
                  .preload(:user)

    @reply_to = params[:reply_to].try(:to_i)
  end

  def new
    @blog = Blog.find_by(urlName: params[:blog_name])
    unless @blog && @blog.can_edit(current_user)
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
      return
    end
    @post = Post.create
    @cats = {}
    @blog.categories.each {|c| @cats[c.path] = {name: c.name, val: false}}
    #For editing only
    #@post.categories.each {|c| @cats[c.path] = true}
  end

  def create
    StatsD.increment("post.create")
    blog = Blog.find_by(urlName: params[:blog_name])
    unless blog && blog.can_edit(current_user)
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
      return
    end
                                  
    post = blog.posts.create(title: params[:post][:title],
                             body: params[:post][:body],
                             is_draft: params[:post][:is_draft] || false)
    cats = params[:categories] || []
    cats.each do |k, v|
      c = blog.categories.find_by_path(k)
      unless c.nil?
        if v == 1
          post.categories << c
        end
      end
    end
    redirect_to edit_post_path(post_id: post.id)
  end

  def edit
    @post = Post.find(params[:post_id])
    if @post.nil? || !@post.can_edit(current_user)
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
      return
    end

    @cats = {}
    @post.blog.categories.each {|c| @cats[c.path] = {name: c.name, value: false}}
    @post.categories.each {|c| @cats[c.path] = {name: c.name, value: true}}
    
    @post_or_update = @post.nil? ? "Post" : "Update"
  end

  def update
    StatsD.increment("post.update")
    @post = Post.find(params[:post_id])
    if @post.nil? || !@post.can_edit(current_user)
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
      return
    end
    @post.update(post_params)
    @post.save

    cats = params[:categories] || []
    cats.each do |k, v|
      c = @post.blog.categories.find_by_path(k)
      unless c.nil?
        if v.to_i == 1
          @post.categories << c
        else
          @post.categories.delete c
        end
      end
    end
    
    redirect_to edit_post_path
  end

  private

  def post_params
    params.require(:post)
      .permit(:title, :body, :is_draft, :created_at)
  end
end
