class UserController < ApplicationController
  def new
    @user = User.new
  end

  def create
    @user = User.new(user_params)
    
    unless simple_captcha_valid?
      flash.now[:alert] = "Captcha was not entered correctly"
      render :new
      return
    end

    if @user.save
      StatsD.increment("user.signup.success")
      session[:user_id] = @user.id
      flash[:notice] = "Account created successfully!"
      redirect_to root_path
    else
      StatsD.increment("user.signup.failure")
      flash.now[:alerts] = @user.f_errors
      render :new
    end
  end

  def dashboard
    if current_user.nil?
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
      return
    end
    blogs = current_user.blogs
    @blogs = blogs.preload_post_counts.all
    @imgs = current_user.image_meta
    @img_new = ImageMetum.new
    @vids = current_user.video_meta
  end

  def upload_image
    begin
      if current_user.nil?
        render file: "#{Rails.root}/public/403.html" , status: :forbidden
        return
      end
      @img = ImageMetum.create(img_params)
      @img.user = current_user
      if !@img.save
        flash[:alerts] = @img.errors.full_messages
        StatsD.increment("image.uploaded.failure")
      else
        StatsD.increment("image.uploaded.success")
      end
    rescue
      #This fires if they don't select an image
      #We don't want to display a message
    end
    redirect_to :dashboard
  end

  def upload_video
    begin
      if current_user.nil?
        render file: "#{Rails.root}/public/403.html" , status: :forbidden
        return
      end
      vid = current_user.video_meta.create(vid_params)
      if !vid.save
        flash[:alerts] = vid.errors.full_messages
        StatsD.increment("video.uploaded.failure")
      else
        StatsD.increment("video.upload.success")
      end
    rescue
      #No video selected
    end
    redirect_to :dashboard
  end

  def edit
    @user = current_user
    if @user.nil?
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
      return
    end
  end

  def update
    StatsD.increment("user.update")
    if current_user.nil?
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
      return
    end

    unless current_user.update(params[:user].permit(:display_name, :email))
      flash.now[:alerts] = current_user.errors.full_messages
      @current_user = nil #Used to force a refresh of current user
    else
      flash.now[:notice] = "Success!"
    end
    @user = current_user
    render :edit
  end

  def change_password
    @user = current_user
    if @user.nil?
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
      return
    end

    unless current_user.authenticate(params[:user][:old_password])
      flash.now[:alert] = "Current password is incorrect!"
      render :edit
      return
    end
    
    unless current_user.update(params[:user].permit(:password, :password_confirmation))
      flash.now[:alerts] = current_user.errors.full_messages
      render :edit
      return
    end
    flash.now[:notice] = "Success!"
    render :edit
    return
  end

  def admin_dash
    unless current_user and current_user.admin?
      render file: "#{Rails.root}/public/403.html" , status: :forbidden
      return
    end
    @users = User.order(created_at: :desc).limit(20).all
    @blogs = Blog.order(created_at: :desc).limit(20).all
  end

  
  def summary
    user = User.find_by(username: params[:uname])
    if user.nil?
      render file: "#{Rails.root}/public/404.html" , status: :not_found
      return
    end
    
    @posts = user.viewable_posts(current_user)
               .eager_load(:blog)
    @comments = user
                  .viewable_comments(current_user)
                  .eager_load(:post)
    @name = user.display_name
    @name = user.username if @name.blank?
  end

  private

  def img_params
    params.require(:image)
      .permit(:img)
  end

  def vid_params
    params.require(:video)
      .permit(:vid)
  end
  
  def user_params
    params.require(:user)
      .permit(:display_name,
              :username,
              :email,
              :password,
              :password_confirmation)
  end
end
