class Blog < ApplicationRecord
  include Rails.application.routes.url_helpers
  mount_uploader :logo, ImageUploader
  
  has_many :posts
  belongs_to :user
  has_many :pages
  has_many :categories

  preload_counts :posts

  validates :title, presence: { message: "Blog title cannot be blank" }
  validates :urlName,
            presence: { message: "Blog url cannot be blank" },
            uniqueness: { message: "That blog url is already in use!" }
  validates :slogan,
            presence: { message: "Blog slogan cannot be blank" }

  validate :validate_colors

  def validate_colors
    errors.add(:bg, "Background color is invalid") if @bgErr
    errors.add(:fg, "Foreground color is invalid") if @fgErr
  end
  
  def bg=(arg)
    if arg.size != 7 || arg[0] != "#"
      @bgErr = true
      return
    end
    begin
      self.bg_color = Integer(arg[1..], 16)
      @bgErr = false
    rescue
      @bgErr = true
    end
  end

  def fg=(arg)
    if arg.size != 7 || arg[0] != "#"
      @fgErr = true
      return
    end
    begin
      self.fg_color = Integer(arg[1..], 16)
      @fgErr = false
    rescue
      @fgErr = true
    end
  end
  
  def bg
    return nil if self.bg_color.nil?
    return "#%06X" % self.bg_color
  end

  def fg
    return nil if self.fg_color.nil?
    return "#%06X" % self.fg_color
  end

  def can_edit(u)
    return false if self.user_id.nil? || u.nil?
    return self.user_id == u.id
  end

  def path
    main_blog_id = Rails.configuration.pressr.main_blog_id
    return root_path if !main_blog_id.nil? && main_blog_id == self.id
    return blog_path(blog_name: self.urlName) unless self.urlName.nil?
    return root_path
  end

  def logo_path
    return self.logo.url unless self.logo.blank?
    return self.img_url #Legacy
  end
end
