require 'github/markup'

class Post < ApplicationRecord
  include PgSearch::Model
  pg_search_scope :search,
                  against: [:title, :body],
                  order_within_rank: "posts.updated_at DESC"
  
  belongs_to :blog
  has_many :comments
  has_and_belongs_to_many :categories, -> { distinct }

  preload_counts :comments

  def author
    self.blog.user
  end

  def friendly_title
    title = (self.title.nil? || self.title.empty?) ? "[No Title]" : self.title
    return "[Draft] #{title}" if self.is_draft
    return title
  end

  def can_edit(user)
    return user == self.author
  end
end
