class User < ApplicationRecord
  has_secure_password
  has_many :blogs
  has_many :posts, through: :blogs
  has_many :comments
  
  has_many :image_meta
  has_many :video_meta

  validates :email, presence: true, uniqueness: true, email: true
  validates :display_name, presence: true
  validates :username, presence: true, uniqueness: true
  
  validates :password, :presence => true,
            :confirmation => true,
            :length => {:within => 6..40},
            :on => :create
  validates :password, :confirmation => true,
            :length => {:within => 6..40},
            :allow_blank => true,
            :on => :update

  def f_errors
    self.errors.full_messages.map { |x| x.capitalize }
  end

  def color
    case self.role
    when 0 #User
      return ''
    when 1 #Admin
      return '#FF3333'
    else
      return ''
    end
  end

  def can_create_blog
    self.role == 1 || Rails.configuration.pressr.allow_user_blogs
  end

  def admin?
    self.role == 1
  end

  def viewable_posts(user = nil)
    posts = self.posts.order(created_at: :desc)
              .joins(:blog)
    if user.nil?
      posts = posts.where(is_draft: false).all
    elsif !user.admin?
      posts = posts
                .where(blogs: { user_id: user.id })
                .or(posts.where(posts: {is_draft: false}))
    end 
    posts.order(created_at: :desc).all
  end

  def viewable_comments(user = nil)
    comments = self.comments
                 .joins(post: [:blog])

    if user.nil?
      comments = comments
                   .where(posts: {is_draft: false}, deleted: false)
    elsif !user.admin?
      comments = comments
                   .where(blogs: { user_id: user.id })
                   .or(comments.where(posts: {is_draft: false}))
    end
    comments.order(created_at: :desc)
             .all
  end
end
